@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2012 Canonical
+ * Copyright (C) 2010-2013 Canonical
  *
  * Portions of this code original from the Linux-ready Firmware Developer Kit
  *
@@ -26,27 +26,24 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <inttypes.h>
+#include <stdbool.h>
 
 static fwts_list *memory_map_list;
 static fwts_acpi_table_info *mcfg_table;
 
-/* Defined in PCI Firmware Specification 3.0 */
-struct mcfg_entry {
-	unsigned int low_address;
-	unsigned int high_address;
-	unsigned short segment;
-	unsigned char start_bus;
-	unsigned char end_bus;
-	unsigned char  reserved[4];
-} __attribute__ ((packed));
-
-static void compare_config_space(fwts_framework *fw, int segment, int device, unsigned char *space)
+static void compare_config_space(
+	fwts_framework *fw,
+	const uint16_t segment,
+	const uint32_t device,
+	const uint8_t *space)
 {
 	fwts_list *lspci_output;
 	fwts_list_link *item;
+	int status;
 
 	char command[PATH_MAX];
-	char compare_line[1024];
+	char compare_line[50];
 
 	snprintf(compare_line, sizeof(compare_line),
 		"%02x %02x %02x %02x %02x %02x %02x %02x %02x %02x %02x %02x %02x %02x %02x %02x",
@@ -55,30 +52,39 @@ static void compare_config_space(fwts_framework *fw, int segment, int device, un
 		space[8],  space[9],  space[10], space[11],
 		space[12], space[13], space[14], space[15]);
 
-	snprintf(command, sizeof(command), "%s -vxxx -s %i:%i",
+	snprintf(command, sizeof(command), "%s -vxxx -s %" PRIu16 ":%" PRIu32,
 		fw->lspci, segment, device);
 
-	if (fwts_pipe_exec(command, &lspci_output) == FWTS_EXEC_ERROR) {
+	if (fwts_pipe_exec(command, &lspci_output, &status) != FWTS_OK) {
 		fwts_log_warning(fw, "Could not execute %s", command);
 		return;
 	}
 
+	if (lspci_output == NULL) {
+		fwts_log_warning(fw,
+			"Failed to get lspci info for %" PRIu16 ":%" PRIu32,
+			segment, device);
+		return;
+	}
+
 	fwts_list_foreach(item, lspci_output) {
 		char *line = fwts_text_list_text(item);
 
 		fwts_chop_newline(line);
 
-		if (strncmp(line, "00: ",4)==0) {
+		if (strncmp(line, "00: ", 4) ==0) {
 			if (strcmp(&line[4], compare_line)) {
-				fwts_log_info(fw, "%s is read from MMCONFIG, but traditional gives :\n-%s-\n", &line[4], compare_line);
+				fwts_log_info(fw,
+					"%s is read from MMCONFIG, but config "
+					"space gives :\n-%s-\n", &line[4], compare_line);
 				fwts_failed(fw, LOG_LEVEL_MEDIUM,
 					"PCIConfigSpaceBad",
-					"PCI config space appears to not work");
+					"PCI config space appears to not work.");
 			} else
-				fwts_passed(fw, "PCI config space verified");
+				fwts_passed(fw, "PCI config space verified.");
 
 			fwts_text_list_free(lspci_output);
-			return ;
+			return;
 		}
 	}
 	fwts_text_list_free(lspci_output);
@@ -95,7 +101,9 @@ static int mcfg_init(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 	if (mcfg_table == NULL) {
-		fwts_log_error(fw, "ACPI table MCFG not found. This table is required to check for PCI Express*");
+		fwts_log_error(fw,
+			"ACPI table MCFG not found. This table is "
+			"required to check for PCI Express*");
 		return FWTS_ERROR;
 	}
 
@@ -104,6 +112,8 @@ static int mcfg_init(fwts_framework *fw)
 
 static int mcfg_deinit(fwts_framework *fw)
 {
+	FWTS_UNUSED(fw);
+
 	if (memory_map_list)
 		fwts_memory_map_table_free(memory_map_list);
 
@@ -113,18 +123,11 @@ static int mcfg_deinit(fwts_framework *fw)
 static int mcfg_test1(fwts_framework *fw)
 {
 	int nr, i;
-	const uint8_t *table_ptr;
-	const uint8_t *table_page;
-	void *mapped_table_page;
-	struct mcfg_entry *table, firstentry;
-	int failed = 0;
-	int mcfg_size;
+	fwts_acpi_table_mcfg *mcfg = (fwts_acpi_table_mcfg*)mcfg_table->data;
+	fwts_acpi_mcfg_configuration *config;
+	bool failed = false;
+	ssize_t mcfg_size;
 	const char *memory_map_name;
-	int page_size;
-
-	page_size = sysconf(_SC_PAGESIZE);
-	if (page_size == -1)
-		page_size = 4096;
 
 	memory_map_name = fwts_memory_map_name(fw->firmware_type);
 
@@ -145,21 +148,21 @@ static int mcfg_test1(fwts_framework *fw)
 	}
 
 	mcfg_size = mcfg_table->length;
-	mcfg_size -= 36; /* general ACPI header */
-	mcfg_size -= 8;  /* 8 bytes of padding */
+	mcfg_size -= sizeof(fwts_acpi_table_mcfg);
 
-	if ((int)mcfg_size<0) {
+	if (mcfg_size < 0) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "MCFGInvalidSize",
-			"Invalid MCFG ACPI table size: got %d bytes expecting more",
-			mcfg_size + 36 + 8);
+			"Invalid MCFG ACPI table size: got %zd bytes expecting more",
+			mcfg_size + sizeof(fwts_acpi_table_mcfg));
 		fwts_tag_failed(fw, FWTS_TAG_ACPI_INVALID_TABLE);
 		fwts_advice(fw,
-			"MCFG table must be least %d bytes (header size) with "
-			"multiples of %d bytes for each MCFG entry.",
-			36+8, (int)sizeof(struct mcfg_entry));
+			"MCFG table must be least %zd bytes (header size) with "
+			"multiples of %zd bytes for each MCFG entry.",
+			sizeof(fwts_acpi_table_mcfg),
+			sizeof(fwts_acpi_mcfg_configuration));
 		return FWTS_ERROR;
 	}
-	nr = mcfg_size / sizeof(struct mcfg_entry);
+	nr = mcfg_size / sizeof(fwts_acpi_mcfg_configuration);
 
 	if (!nr) {
 		fwts_failed(fw, LOG_LEVEL_MEDIUM, "MCFGNoEntries",
@@ -167,72 +170,102 @@ static int mcfg_test1(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 
-	if ((nr * sizeof(struct mcfg_entry)) != mcfg_size) {
+	if (mcfg_size != (ssize_t)(nr * sizeof(fwts_acpi_mcfg_configuration))) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "MCFGInvalidSize2",
 			"MCFG table is not a multiple of record size");
 		fwts_tag_failed(fw, FWTS_TAG_ACPI_INVALID_TABLE);
 		return FWTS_ERROR;
 	}
 
-	fwts_log_info(fw, "MCFG table found, size is %i bytes (excluding header) (%i entries).",
-			mcfg_size, nr);
+	fwts_log_info(fw,
+		"MCFG table found, size is %zd bytes (excluding header) (%i entries).",
+		mcfg_size, nr);
 
-	table_page = table_ptr = (const uint8_t *)mcfg_table->data;
-
-	if (table_page == NULL) {
+	if (mcfg == NULL) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "MCFGInvalidTable",
 			"Invalid MCFG ACPI table");
 		fwts_tag_failed(fw, FWTS_TAG_ACPI_INVALID_TABLE);
 		return FWTS_ERROR;
 	}
 
-	table_ptr += 36 + 8; /* 36 for the acpi header, 8 for padding */
-        table = (struct mcfg_entry *) table_ptr;
-
-	firstentry = *table;
-
 	if (memory_map_list == NULL)
 		fwts_failed(fw, LOG_LEVEL_MEDIUM, "MMapUnreadable",
 			"Cannot check MCFG mmio space against memory map table: could not read memory map table.");
 
-	for (i = 0; i<nr; i++) {
-		fwts_log_info(fw, "Entry address : 0x%x\n", table->low_address);
+	config = &mcfg->configuration[0];
+	for (i = 0; i < nr; i++, config++) {
+		fwts_log_info_verbatum(fw, "Configuration Entry #%d:", i);
+		fwts_log_info_verbatum(fw, "  Base Address  : 0x%" PRIx64, config->base_address);
+		fwts_log_info_verbatum(fw, "  Segment       : %" PRIu8, config->pci_segment_group_number);
+		fwts_log_info_verbatum(fw, "  Start bus     : %" PRIu8, config->start_bus_number);
+		fwts_log_info_verbatum(fw, "  End bus       : %" PRIu8, config->end_bus_number);
 
 		if ((memory_map_list != NULL) &&
-		    (!fwts_memory_map_is_reserved(memory_map_list, table->low_address))) {
+		    (!fwts_memory_map_is_reserved(memory_map_list, config->base_address))) {
 
-			fwts_failed(fw, LOG_LEVEL_MEDIUM, "MCFGMMIONotReserved",
-				"MCFG mmio config space at 0x%x is not reserved in the memory map table", table->low_address);
+			fwts_failed(fw, LOG_LEVEL_LOW, "MCFGMMIONotReserved",
+				"MCFG mmio config space at 0x%" PRIx64
+				" is not reserved in the memory map table",
+				config->base_address);
 			fwts_tag_failed(fw, FWTS_TAG_BIOS);
+
 			fwts_advice(fw,
-				"The PCI Express specification states that the PCI Express configuration space should "
-				"be defined in the MCFG table and *maybe* optionally defined in the %s "
-				"if ACPI MCFG is present. "
-				"Linux checks if the region is reserved in the memory map table and will reject the "
-				"MMCONFIG if there is a discrepency between MCFG and the memory map table for the "
-				"PCI Express region.  [See arch/x86/pci/mmconfig-shared.c pci_mmcfg_reject_broken()]. "
-				"It is recommended that this is defined in the %s table for Linux.",
+				"The PCI Express specification states that the "
+				"PCI Express configuration space should "
+				"be defined in the MCFG table and *maybe* "
+				"optionally defined in the %s if ACPI MCFG is "
+				"present. Linux checks if the region is reserved "
+				"in the memory map table and will reject the "
+				"MMCONFIG if there is a discrepency between MCFG "
+				"and the memory map table for the PCI Express region. "
+				"[See arch/x86/pci/mmconfig-shared.c pci_mmcfg_reject_broken()]. "
+				"It is recommended that this is defined in the "
+				"%s table for Linux.",
 				memory_map_name, memory_map_name);
-			failed++;
+			failed = true;
 		}
-
-		fwts_log_info_verbatum(fw, "High  address : 0x%x \n", table->high_address);
-		fwts_log_info_verbatum(fw, "Segment       : %i \n", table->segment);
-		fwts_log_info_verbatum(fw, "Start bus     : %i \n", table->start_bus);
-		fwts_log_info_verbatum(fw, "End bus       : %i \n", table->end_bus);
-
-		table++;
 	}
 	if (!failed)
 		fwts_passed(fw, "MCFG mmio config space is reserved in memory map table.");
 
-	if ((mapped_table_page = fwts_mmap(firstentry.low_address, page_size)) == FWTS_MAP_FAILED) {
-		fwts_log_error(fw, "Cannot mmap table at 0x%x.", firstentry.low_address);
+
+	return FWTS_OK;
+}
+
+#define SINGLE_CONFIG_TABLE_SIZE \
+	(sizeof(fwts_acpi_table_mcfg) + sizeof(fwts_acpi_mcfg_configuration))
+
+static int mcfg_test2(fwts_framework *fw)
+{
+	fwts_acpi_table_mcfg *mcfg = (fwts_acpi_table_mcfg *)mcfg_table->data;
+	fwts_acpi_mcfg_configuration *config;
+	uint8_t *mapped_table_page;
+	size_t page_size;
+
+	page_size = fwts_page_size();
+
+	if (mcfg == NULL) {
+		fwts_failed(fw, LOG_LEVEL_HIGH, "MCFGInvalidTable",
+			"Invalid MCFG ACPI table");
+		fwts_tag_failed(fw, FWTS_TAG_ACPI_INVALID_TABLE);
 		return FWTS_ERROR;
 	}
 
-	compare_config_space(fw, firstentry.segment, 0, (unsigned char *)mapped_table_page);
+	/* Need at least one config entry */
+	if (mcfg_table->length < SINGLE_CONFIG_TABLE_SIZE) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "MCFGNoEntries",
+			"No MCFG ACPI table entries");
+		return FWTS_ERROR;
+	}
 
+	config = &mcfg->configuration[0];
+
+	/* Sanity check on first config */
+	if ((mapped_table_page = fwts_mmap(config->base_address, page_size)) == FWTS_MAP_FAILED) {
+		fwts_log_error(fw, "Cannot mmap table at 0x%" PRIx64 ".", config->base_address);
+		return FWTS_ERROR;
+	}
+	compare_config_space(fw, config->pci_segment_group_number, 0, mapped_table_page);
 	fwts_munmap(mapped_table_page, page_size);
 
 	return FWTS_OK;
@@ -240,6 +273,7 @@ static int mcfg_test1(fwts_framework *fw)
 
 static fwts_framework_minor_test mcfg_tests[] = {
 	{ mcfg_test1, "Validate MCFG table." },
+	{ mcfg_test2, "Validate MCFG PCI config space." },
 	{ NULL, NULL }
 };
 
@@ -250,6 +284,6 @@ static fwts_framework_ops mcfg_ops = {
 	.minor_tests = mcfg_tests
 };
 
-FWTS_REGISTER(mcfg, &mcfg_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
+FWTS_REGISTER("mcfg", &mcfg_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
 
 #endif
