@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2012 Canonical
+ * Copyright (C) 2010-2013 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -100,6 +100,6 @@ static fwts_framework_ops osilinux_ops = {
 	.minor_tests = osilinux_tests
 };
 
-FWTS_REGISTER(osilinux, &osilinux_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH);
+FWTS_REGISTER("osilinux", &osilinux_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH);
 
 #endif
