@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2012 Canonical
+ * Copyright (C) 2010-2013 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -83,6 +83,6 @@ static fwts_framework_ops power_button_ops = {
 	.minor_tests = power_button_tests
 };
 
-FWTS_REGISTER(power_button, &power_button_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_INTERACTIVE);
+FWTS_REGISTER("power_button", &power_button_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_INTERACTIVE);
 
 #endif
