@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006, Intel Corporation
- * Copyright (C) 2010-2012 Canonical
+ * Copyright (C) 2010-2013 Canonical
  *
  * This code was originally part of the Linux-ready Firmware Developer Kit
  *
@@ -30,6 +30,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <inttypes.h>
 
 static off_t ebda_addr = FWTS_NO_EBDA;
 
@@ -57,6 +58,8 @@ static int ebda_init(fwts_framework *fw)
 
 static int ebda_deinit(fwts_framework *fw)
 {
+	FWTS_UNUSED(fw);
+
 	fwts_klog_free(memory_map);
 
 	return FWTS_OK;
@@ -73,19 +76,20 @@ static int ebda_test1(fwts_framework *fw)
 	fwts_log_info(fw,
 		"The Extended BIOS Data Area (EBDA) is normally located at "
 		"the end of the low 640K region and is typically 2-4K in "
-		"size. It should be reserved in the %s table.", 
+		"size. It should be reserved in the %s table.",
 		memory_map_name);
 
 	entry = fwts_memory_map_info(memory_map, (uint64_t)ebda_addr);
 	if ((entry != NULL) &&
 	    (entry->type == FWTS_MEMORY_MAP_RESERVED ||
 	     entry->type == FWTS_MEMORY_MAP_ACPI)) {
-		fwts_passed(fw, "EBDA region mapped at 0x%lx and reserved as a %lldK region in the %s table at 0x%llx..0x%llx.",
+		fwts_passed(fw, "EBDA region mapped at 0x%lx and reserved as a %" PRId64
+			"K region in the %s table at 0x%" PRIx64 "..0x%" PRIx64 ".",
 			ebda_addr,
-			(unsigned long long int)(entry->end_address - entry->start_address) / 1024,
+			(entry->end_address - entry->start_address) / 1024,
 			memory_map_name,
-			(unsigned long long int)entry->start_address,
-			(unsigned long long int)entry->end_address);
+			entry->start_address,
+			entry->end_address);
 	} else {
 		fwts_failed(fw, LOG_LEVEL_MEDIUM,
 			"EBDAMappedNotReserved",
@@ -109,6 +113,6 @@ static fwts_framework_ops ebda_ops = {
 	.minor_tests = ebda_tests
 };
 
-FWTS_REGISTER(ebda, &ebda_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
+FWTS_REGISTER("ebda", &ebda_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
 
 #endif
