@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2012 Canonical
+ * Copyright (C) 2011-2013 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -226,6 +226,8 @@ static int mpdump_init(fwts_framework *fw)
 
 static int mpdump_deinit(fwts_framework *fw)
 {
+	FWTS_UNUSED(fw);
+
 	return fwts_mp_data_free(&mp_data);
 }
 
@@ -526,6 +528,6 @@ static fwts_framework_ops mpdump_ops = {
 	.minor_tests = mpdump_tests,
 };
 
-FWTS_REGISTER(mpdump, &mpdump_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UTILS | FWTS_FLAG_ROOT_PRIV);
+FWTS_REGISTER("mpdump", &mpdump_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UTILS | FWTS_FLAG_ROOT_PRIV);
 
 #endif
