@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006, Intel Corporation
- * Copyright (C) 2010-2012 Canonical
+ * Copyright (C) 2010-2013 Canonical
  *
  * This file was originally part of the Linux-ready Firmware Developer Kit
  *
@@ -37,19 +37,21 @@
 #include <time.h>
 #include <math.h>
 #include <ctype.h>
+#include <inttypes.h>
 
 #define FWTS_CPU_PATH	"/sys/devices/system/cpu"
 
 typedef struct {
-	unsigned long	Hz;
-	unsigned long	speed;
+	uint32_t	Hz;
+	uint64_t	speed;
 } fwts_cpu_freq;
 
 static int number_of_speeds = -1;
 static int total_tests = 1;
 static int performed_tests = 0;
 static int no_cpufreq = 0;
-static unsigned long top_speed = 0;
+static uint64_t top_speed = 0;
+static int num_cpus;
 
 #define GET_PERFORMANCE_MAX (0)
 #define GET_PERFORMANCE_MIN (1)
@@ -125,66 +127,26 @@ static void set_HZ(fwts_framework *fw, const int cpu, const unsigned long Hz)
 
 }
 
-static unsigned long get_performance(const int cpu)
-{
-	cpu_set_t mask, oldset;
-	time_t current;
-	unsigned long loopcount = 0;
-
-	/* First, go to the right cpu */
-
-	sched_getaffinity(0, sizeof(oldset), &oldset);
-
-	CPU_ZERO(&mask);
-	CPU_SET(cpu, &mask);
-	sched_setaffinity(0, sizeof(mask), &mask);
-
-	current = time(NULL);
-	while (current == time(NULL))
-		sched_yield();
-	current = time(NULL);
-
-	do {
-		double A, B;
-		int i;
-		A = 1.234567;
-		B = 3.121213;
-		for (i = 0; i < 100; i++) {
-			A = A * B;
-			B = A * A;
-			A = A - B + sqrt(A);
-			A = A * B;
-			B = A * A;
-			A = A - B + sqrt(A);
-			A = A * B;
-			B = A * A;
-			A = A - B + sqrt(A);
-			A = A * B;
-			B = A * A;
-			A = A - B + sqrt(A);
-		}
-		loopcount++;
-	} while (current == time(NULL));
-
-	sched_setaffinity(0, sizeof(oldset), &oldset);
-
-	return loopcount;
-}
-
-
-static unsigned long get_performance_repeat(fwts_framework *fw,
-	int cpu, unsigned long Hz, int count, int type)
+static int get_performance_repeat(
+	fwts_framework *fw,
+	const int cpu,
+	const int count,
+	const int type,
+	uint64_t *retval)
 {
 	int i;
 
-	unsigned long max = 0, min = ULONG_MAX, real_count = 0;
-	unsigned long long cumulative = 0;
-	unsigned long retval;
+	uint64_t max = 0;
+	uint64_t min = ~0;
+	uint64_t real_count = 0;
+	uint64_t cumulative = 0;
 
-	set_HZ(fw, cpu, Hz);
 	for (i = 0; i < count; i++) {
-		unsigned long temp;
-		temp = get_performance(cpu);
+		uint64_t temp;
+
+		if (fwts_cpu_performance(fw, cpu, &temp) != FWTS_OK)
+			return FWTS_ERROR;
+
 		if (temp) {
 			if (temp < min)
 				min = temp;
@@ -199,19 +161,19 @@ static unsigned long get_performance_repeat(fwts_framework *fw,
 
 	switch (type) {
 	case GET_PERFORMANCE_MAX:
-		retval = max;
+		*retval = max;
 		break;
 	case GET_PERFORMANCE_MIN:
-		retval = min;
+		*retval = min;
 		break;
 	case GET_PERFORMANCE_AVG:
-		retval = cumulative/real_count;
+		*retval = cumulative / real_count;
 		break;
 	default:
-		retval = 0;
+		*retval = 0;
 		break;
 	}
-	return retval;
+	return FWTS_OK;
 }
 
 static char *HzToHuman(unsigned long hz)
@@ -222,11 +184,11 @@ static char *HzToHuman(unsigned long hz)
 	Hz = hz;
 
 	if (Hz > 1500000) {
-		snprintf(buffer, sizeof(buffer), "%6.2f Ghz",
+		snprintf(buffer, sizeof(buffer), "%6.2f GHz",
 			(Hz+50000.0) / 1000000);
 		return buffer;
 	} else if (Hz > 1000) {
-		snprintf(buffer, sizeof(buffer), "%6lli Mhz",
+		snprintf(buffer, sizeof(buffer), "%6lli MHz",
 			(Hz+500) / 1000);
 		return buffer;
 	} else {
@@ -237,11 +199,11 @@ static char *HzToHuman(unsigned long hz)
 
 
 
-static unsigned long get_claimed_hz(const int cpu)
+static uint32_t get_claimed_hz(const int cpu)
 {
 	char path[PATH_MAX];
 	char *buffer;
-	unsigned long value = 0;
+	uint32_t value = 0;
 
 	cpu_mkpath(path, sizeof(path), cpu, "scaling_max_freq");
 
@@ -263,7 +225,7 @@ static void do_cpu(fwts_framework *fw, int cpu)
 	int speedcount;
 	static int warned=0;
 	int warned_PSS = 0;
-	unsigned long cpu_top_speed = 0;
+	uint64_t cpu_top_speed = 0;
 
 	memset(freqs, 0, sizeof(freqs));
 	memset(line, 0, sizeof(line));
@@ -284,7 +246,7 @@ static void do_cpu(fwts_framework *fw, int cpu)
 
 	if (total_tests == 1)
 		total_tests = (2+count_ints(line)) *
-			sysconf(_SC_NPROCESSORS_CONF) + 2;
+			num_cpus + 2;
 
 	c = line;
 	i = 0;
@@ -298,7 +260,12 @@ static void do_cpu(fwts_framework *fw, int cpu)
 
 		freqs[i].Hz = strtoull(c, NULL, 10);
 		set_HZ(fw, cpu, freqs[i].Hz);
-		freqs[i].speed = get_performance(cpu);
+
+		if (fwts_cpu_performance(fw, cpu, &freqs[i].speed) != FWTS_OK) {
+			fwts_log_error(fw, "Failed to get CPU performance for "
+				"CPU frequency %" PRIu32 " Hz.", freqs[i].Hz);
+			freqs[i].speed = 0;
+		}
 		if (freqs[i].speed > cpu_top_speed)
 			cpu_top_speed = freqs[i].speed;
 
@@ -317,7 +284,7 @@ static void do_cpu(fwts_framework *fw, int cpu)
 	fwts_log_info_verbatum(fw, " Frequency | Relative Speed | Bogo loops");
 	fwts_log_info_verbatum(fw, "-----------+----------------+-----------");
 	for (i = 0; i < speedcount; i++)
-		fwts_log_info_verbatum(fw, "%9s |     %5.1f %%    | %9lu",
+		fwts_log_info_verbatum(fw, "%9s |     %5.1f %%    | %9" PRIu64,
 			HzToHuman(freqs[i].Hz),
 			100.0 * freqs[i].speed/cpu_top_speed,
 			freqs[i].speed);
@@ -360,13 +327,16 @@ static void do_cpu(fwts_framework *fw, int cpu)
 		if (freqs[i].speed > freqs[i+1].speed)
 			fwts_failed(fw, LOG_LEVEL_MEDIUM,
 				"CPUFreqSlowerOnCPU",
-				"Supposedly higher frequency %s is slower (%lu bogo loops) than frequency %s (%lu bogo loops) on CPU %i.",
+				"Supposedly higher frequency %s is slower (%" PRIu64
+				" bogo loops) than frequency %s (%" PRIu64 
+				" bogo loops) on CPU %i.",
 				HzToHuman(freqs[i+1].Hz), freqs[i+1].speed,
 				HzToHuman(freqs[i].Hz), freqs[i].speed,
 				cpu);
 		if (freqs[i].Hz > get_claimed_hz(cpu) && !warned_PSS) {
 			warned_PSS = 1;
-			fwts_warning(fw, "Frequency %lu not achievable; _PSS limit of %lu in effect?",
+			fwts_warning(fw, "Frequency %" PRIu32
+				" not achievable; _PSS limit of %" PRIu32 " in effect?",
 				freqs[i].Hz, get_claimed_hz(cpu));
 		}
 	}
@@ -446,7 +416,7 @@ static void do_sw_all_test(fwts_framework *fw)
 {
 	DIR *dir;
 	struct dirent *entry;
-	unsigned long highperf, lowperf;
+	uint64_t highperf, lowperf;
 	int first_cpu_index = -1;
 	int cpu;
 
@@ -467,11 +437,20 @@ static void do_sw_all_test(fwts_framework *fw)
 	closedir(dir);
 
 	/* All CPUs at the lowest frequency */
-	lowperf = 100 * get_performance_repeat(fw, first_cpu_index,
-						0, 5, GET_PERFORMANCE_MIN) / top_speed;
+	if (get_performance_repeat(fw, first_cpu_index, 5, GET_PERFORMANCE_MIN, &lowperf) != FWTS_OK) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "CPUFreqSW_ALLGetPerf",
+			"Failed to get CPU performance.");
+		return;
+	}
+	lowperf = (lowperf * 100) / top_speed;
+
 	highest_speed(fw, first_cpu_index);
-	highperf = 100 * get_performance_repeat(fw, first_cpu_index,
-						0, 5, GET_PERFORMANCE_MAX) / top_speed;
+	if (get_performance_repeat(fw, first_cpu_index, 5, GET_PERFORMANCE_MAX, &highperf) != FWTS_OK) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "CPUFreqSW_ALLGetPerf",
+			"Failed to get CPU performance.");
+		return;
+	}
+	highperf = (highperf * 100) / top_speed;
 
 	if (lowperf >= highperf)
 		fwts_failed(fw, LOG_LEVEL_MEDIUM,
@@ -493,7 +472,7 @@ static void do_sw_any_test(fwts_framework *fw)
 {
 	DIR *dir;
 	struct dirent *entry;
-	unsigned long highperf, lowperf;
+	uint64_t highperf, lowperf;
 	int first_cpu_index = -1;
 	int cpu;
 
@@ -514,8 +493,12 @@ static void do_sw_any_test(fwts_framework *fw)
 	rewinddir(dir);
 
 	/* All CPUs at the lowest frequency */
-	lowperf = 100 * get_performance_repeat(fw, first_cpu_index,
-						0, 5, GET_PERFORMANCE_MIN) / top_speed;
+	if (get_performance_repeat(fw, first_cpu_index, 5, GET_PERFORMANCE_MIN, &lowperf) != FWTS_OK) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "CPUFreqSW_ANYGetPerf",
+			"Failed to get CPU performance.");
+		return;
+	}
+	lowperf = (100 * lowperf) / top_speed;
 
 	highest_speed(fw, first_cpu_index);
 
@@ -529,8 +512,12 @@ static void do_sw_any_test(fwts_framework *fw)
 	}
 	closedir(dir);
 
-	highperf = 100 * get_performance_repeat(fw, first_cpu_index,
-						0, 5, GET_PERFORMANCE_MAX) / top_speed;
+	if (get_performance_repeat(fw, first_cpu_index, 5, GET_PERFORMANCE_MAX, &highperf) != FWTS_OK) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "CPUFreqSW_ANYGetPerf",
+			"Failed to get CPU performance.");
+		return;
+	}
+	highperf = (100 * highperf) / top_speed;
 
 	if (lowperf >= highperf)
 		fwts_failed(fw, LOG_LEVEL_MEDIUM,
@@ -570,13 +557,24 @@ static void check_sw_any(fwts_framework *fw)
 		return; /* Single processor machine, no point in checking anything */
 
 	/* assume that all processors have the same low performance */
-	low_perf = get_performance(max_cpu);
+	if (fwts_cpu_performance(fw, max_cpu, &low_perf) != FWTS_OK) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			"CPUFreqCPsSetToSW_ANYGetPerf",
+			"Cannot get CPU performance.");
+		return;
+	}
+
 	for (i = 0; i <= max_cpu; i++) {
 		highest_speed(fw, i);
 		if (!cpu_exists(i))
 			continue;
 
-		high_perf = get_performance(i);
+		if (fwts_cpu_performance(fw, i, &high_perf) != FWTS_OK) {
+			fwts_failed(fw, LOG_LEVEL_MEDIUM,
+				"CPUFreqCPsSetToSW_ANYGetPerf",
+				"Cannot get CPU performance.");
+			return;
+		}
 		performed_tests++;
 		fwts_progress(fw, 100 * performed_tests/total_tests);
 		/*
@@ -587,8 +585,14 @@ static void check_sw_any(fwts_framework *fw)
 		for (j = 0; j <= max_cpu; j++)
 			if (i != j)
 				lowest_speed(fw, j);
-		newhigh_perf = get_performance(i);
-		if (high_perf - newhigh_perf > (high_perf - low_perf)/4 &&
+		if (fwts_cpu_performance(fw, i, &newhigh_perf) != FWTS_OK) {
+			fwts_failed(fw, LOG_LEVEL_MEDIUM,
+				"CPUFreqCPsSetToSW_ANYGetPerf",
+				"Cannot get CPU performance.");
+			return;
+		}
+		if ((high_perf > newhigh_perf) &&
+		    (high_perf - newhigh_perf > (high_perf - low_perf)/4) &&
 		    (once == 0) && (high_perf - low_perf > 20)) {
 			fwts_failed(fw, LOG_LEVEL_MEDIUM,
 				"CPUFreqCPUsSetToSW_ANY",
@@ -667,7 +671,7 @@ static int cpufreq_test1(fwts_framework *fw)
 	 * Check for more than one CPU and more than one frequency and
 	 * then do the benchmark set 2
 	 */
-	if (sysconf(_SC_NPROCESSORS_CONF) > 1 && number_of_speeds > 1) {
+	if (num_cpus > 1 && number_of_speeds > 1) {
 		do_sw_all_test(fw);
 		performed_tests++;
 		fwts_progress(fw, 100 * performed_tests/total_tests);
@@ -684,16 +688,26 @@ static int cpufreq_test1(fwts_framework *fw)
 	return FWTS_OK;
 }
 
+static int cpufreq_init(fwts_framework *fw)
+{
+	if ((num_cpus = fwts_cpu_enumerate()) == FWTS_ERROR) {
+		fwts_log_warning(fw, "Cannot determine number of CPUS, defaulting to 1.");
+		num_cpus = 1;
+	}
+	return FWTS_OK;
+}
+
 static fwts_framework_minor_test cpufreq_tests[] = {
 	{ cpufreq_test1, "CPU P-State Checks." },
 	{ NULL, NULL }
 };
 
 static fwts_framework_ops cpufreq_ops = {
+	.init        = cpufreq_init,
 	.description = "CPU frequency scaling tests (takes ~1-2 mins).",
 	.minor_tests = cpufreq_tests
 };
 
-FWTS_REGISTER(cpufreq, &cpufreq_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH_EXPERIMENTAL | FWTS_FLAG_ROOT_PRIV);
+FWTS_REGISTER("cpufreq", &cpufreq_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
 
 #endif
