@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2012 Canonical
+ * Copyright (C) 2011-2013 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@
 #ifdef FWTS_ARCH_INTEL
 
 #include <stdbool.h>
+#include <inttypes.h>
 
 /* Real Mode IDT */
 #define INT_VEC_START		(0x00000000)
@@ -39,7 +40,7 @@ static int csm_test1(fwts_framework *fw)
 	uint8_t  *optROM;
 	uint32_t *intVec;
 	uint32_t int10hVec;
-	int i;
+	uint32_t i;
 	int flag = 0;
 
 	fwts_log_info(fw, "Checking for UEFI Compatibility Support Module (CSM)");
@@ -62,14 +63,14 @@ static int csm_test1(fwts_framework *fw)
 
 	for (i=0; i<BIOS_ROM_REGION_SIZE; i+= 512) {
 		if ((*(optROM+i) == 0x55) && (*(optROM+i+1) == 0xaa)) {
-			int length = *(optROM+i+2) << 9;
-			int ROMstart = BIOS_ROM_REGION_START+i;
-			int ROMend = BIOS_ROM_REGION_START+i+length;
+			uint32_t length = *(optROM+i+2) << 9;
+			uint32_t ROMstart = BIOS_ROM_REGION_START+i;
+			uint32_t ROMend = BIOS_ROM_REGION_START+i+length;
 
 			if ((ROMstart <= int10hVec) && (int10hVec <= ROMend)) {
-				fwts_log_info(fw, "Int 10h jumps to 0x%x in option ROM at: "
+				fwts_log_info(fw, "Int 10h jumps to 0x%" PRIx32 " in option ROM at: "
 					"0x%x..0x%0x",
-					(int)int10hVec, ROMstart, ROMend);
+					int10hVec, ROMstart, ROMend);
 				flag |= VGA_SUPPORT;
 				break;
 			}
@@ -111,6 +112,6 @@ static fwts_framework_ops csm_ops = {
 	.minor_tests = csm_tests
 };
 
-FWTS_REGISTER(csm, &csm_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
+FWTS_REGISTER("csm", &csm_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
 
 #endif
